==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/eventarc_trigger/EventarcTriggerDestination.java <==
package com.hashicorp.cdktf.providers.google.eventarc_trigger;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:41.821Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestination")
@software.amazon.jsii.Jsii.Proxy(EventarcTriggerDestination.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EventarcTriggerDestination extends software.amazon.jsii.JsiiSerializable {

    /**
     * [WARNING] Configuring a Cloud Function in Trigger is not supported as of today.
     * <p>
     * The Cloud Function resource name. Format: projects/{project}/locations/{location}/functions/{function}
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#cloud_function EventarcTrigger#cloud_function}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCloudFunction() {
        return null;
    }

    /**
     * cloud_run_service block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#cloud_run_service EventarcTrigger#cloud_run_service}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunService() {
        return null;
    }

    /**
     * gke block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#gke EventarcTrigger#gke}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGke() {
        return null;
    }

    /**
     * The resource name of the Workflow whose Executions are triggered by the events.
     * <p>
     * The Workflow resource should be deployed in the same project as the trigger. Format: `projects/{project}/locations/{location}/workflows/{workflow}`
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#workflow EventarcTrigger#workflow}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getWorkflow() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EventarcTriggerDestination> {
        java.lang.String cloudFunction;
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService;
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke;
        java.lang.String workflow;

        /**
         * Sets the value of {@link EventarcTriggerDestination#getCloudFunction}
         * @param cloudFunction [WARNING] Configuring a Cloud Function in Trigger is not supported as of today.
         *                      The Cloud Function resource name. Format: projects/{project}/locations/{location}/functions/{function}
         *                      
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#cloud_function EventarcTrigger#cloud_function}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudFunction(java.lang.String cloudFunction) {
            this.cloudFunction = cloudFunction;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getCloudRunService}
         * @param cloudRunService cloud_run_service block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#cloud_run_service EventarcTrigger#cloud_run_service}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudRunService(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService) {
            this.cloudRunService = cloudRunService;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getGke}
         * @param gke gke block.
         *            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#gke EventarcTrigger#gke}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gke(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke) {
            this.gke = gke;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getWorkflow}
         * @param workflow The resource name of the Workflow whose Executions are triggered by the events.
         *                 The Workflow resource should be deployed in the same project as the trigger. Format: `projects/{project}/locations/{location}/workflows/{workflow}`
         *                 
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/eventarc_trigger#workflow EventarcTrigger#workflow}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder workflow(java.lang.String workflow) {
            this.workflow = workflow;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventarcTriggerDestination}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EventarcTriggerDestination build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EventarcTriggerDestination {
        private final java.lang.String cloudFunction;
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService;
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke;
        private final java.lang.String workflow;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudFunction = software.amazon.jsii.Kernel.get(this, "cloudFunction", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cloudRunService = software.amazon.jsii.Kernel.get(this, "cloudRunService", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService.class));
            this.gke = software.amazon.jsii.Kernel.get(this, "gke", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke.class));
            this.workflow = software.amazon.jsii.Kernel.get(this, "workflow", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudFunction = builder.cloudFunction;
            this.cloudRunService = builder.cloudRunService;
            this.gke = builder.gke;
            this.workflow = builder.workflow;
        }

        @Override
        public final java.lang.String getCloudFunction() {
            return this.cloudFunction;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunService() {
            return this.cloudRunService;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGke() {
            return this.gke;
        }

        @Override
        public final java.lang.String getWorkflow() {
            return this.workflow;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudFunction() != null) {
                data.set("cloudFunction", om.valueToTree(this.getCloudFunction()));
            }
            if (this.getCloudRunService() != null) {
                data.set("cloudRunService", om.valueToTree(this.getCloudRunService()));
            }
            if (this.getGke() != null) {
                data.set("gke", om.valueToTree(this.getGke()));
            }
            if (this.getWorkflow() != null) {
                data.set("workflow", om.valueToTree(this.getWorkflow()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestination"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EventarcTriggerDestination.Jsii$Proxy that = (EventarcTriggerDestination.Jsii$Proxy) o;

            if (this.cloudFunction != null ? !this.cloudFunction.equals(that.cloudFunction) : that.cloudFunction != null) return false;
            if (this.cloudRunService != null ? !this.cloudRunService.equals(that.cloudRunService) : that.cloudRunService != null) return false;
            if (this.gke != null ? !this.gke.equals(that.gke) : that.gke != null) return false;
            return this.workflow != null ? this.workflow.equals(that.workflow) : that.workflow == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudFunction != null ? this.cloudFunction.hashCode() : 0;
            result = 31 * result + (this.cloudRunService != null ? this.cloudRunService.hashCode() : 0);
            result = 31 * result + (this.gke != null ? this.gke.hashCode() : 0);
            result = 31 * result + (this.workflow != null ? this.workflow.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/eventarc_trigger/EventarcTriggerDestination.java <==
package com.hashicorp.cdktf.providers.google.eventarc_trigger;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:15.888Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestination")
@software.amazon.jsii.Jsii.Proxy(EventarcTriggerDestination.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EventarcTriggerDestination extends software.amazon.jsii.JsiiSerializable {

    /**
     * cloud_run_service block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#cloud_run_service EventarcTrigger#cloud_run_service}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunService() {
        return null;
    }

    /**
     * gke block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#gke EventarcTrigger#gke}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGke() {
        return null;
    }

    /**
     * http_endpoint block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#http_endpoint EventarcTrigger#http_endpoint}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint getHttpEndpoint() {
        return null;
    }

    /**
     * network_config block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#network_config EventarcTrigger#network_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig getNetworkConfig() {
        return null;
    }

    /**
     * The resource name of the Workflow whose Executions are triggered by the events.
     * <p>
     * The Workflow resource should be deployed in the same project as the trigger. Format: `projects/{project}/locations/{location}/workflows/{workflow}`
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#workflow EventarcTrigger#workflow}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getWorkflow() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EventarcTriggerDestination> {
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService;
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke;
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint httpEndpoint;
        com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig networkConfig;
        java.lang.String workflow;

        /**
         * Sets the value of {@link EventarcTriggerDestination#getCloudRunService}
         * @param cloudRunService cloud_run_service block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#cloud_run_service EventarcTrigger#cloud_run_service}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudRunService(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService) {
            this.cloudRunService = cloudRunService;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getGke}
         * @param gke gke block.
         *            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#gke EventarcTrigger#gke}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gke(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke) {
            this.gke = gke;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getHttpEndpoint}
         * @param httpEndpoint http_endpoint block.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#http_endpoint EventarcTrigger#http_endpoint}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpEndpoint(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint httpEndpoint) {
            this.httpEndpoint = httpEndpoint;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getNetworkConfig}
         * @param networkConfig network_config block.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#network_config EventarcTrigger#network_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkConfig(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig networkConfig) {
            this.networkConfig = networkConfig;
            return this;
        }

        /**
         * Sets the value of {@link EventarcTriggerDestination#getWorkflow}
         * @param workflow The resource name of the Workflow whose Executions are triggered by the events.
         *                 The Workflow resource should be deployed in the same project as the trigger. Format: `projects/{project}/locations/{location}/workflows/{workflow}`
         *                 
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/eventarc_trigger#workflow EventarcTrigger#workflow}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder workflow(java.lang.String workflow) {
            this.workflow = workflow;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventarcTriggerDestination}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EventarcTriggerDestination build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EventarcTriggerDestination}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EventarcTriggerDestination {
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService cloudRunService;
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke gke;
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint httpEndpoint;
        private final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig networkConfig;
        private final java.lang.String workflow;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudRunService = software.amazon.jsii.Kernel.get(this, "cloudRunService", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService.class));
            this.gke = software.amazon.jsii.Kernel.get(this, "gke", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke.class));
            this.httpEndpoint = software.amazon.jsii.Kernel.get(this, "httpEndpoint", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint.class));
            this.networkConfig = software.amazon.jsii.Kernel.get(this, "networkConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig.class));
            this.workflow = software.amazon.jsii.Kernel.get(this, "workflow", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudRunService = builder.cloudRunService;
            this.gke = builder.gke;
            this.httpEndpoint = builder.httpEndpoint;
            this.networkConfig = builder.networkConfig;
            this.workflow = builder.workflow;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunService() {
            return this.cloudRunService;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGke() {
            return this.gke;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint getHttpEndpoint() {
            return this.httpEndpoint;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig getNetworkConfig() {
            return this.networkConfig;
        }

        @Override
        public final java.lang.String getWorkflow() {
            return this.workflow;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudRunService() != null) {
                data.set("cloudRunService", om.valueToTree(this.getCloudRunService()));
            }
            if (this.getGke() != null) {
                data.set("gke", om.valueToTree(this.getGke()));
            }
            if (this.getHttpEndpoint() != null) {
                data.set("httpEndpoint", om.valueToTree(this.getHttpEndpoint()));
            }
            if (this.getNetworkConfig() != null) {
                data.set("networkConfig", om.valueToTree(this.getNetworkConfig()));
            }
            if (this.getWorkflow() != null) {
                data.set("workflow", om.valueToTree(this.getWorkflow()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestination"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EventarcTriggerDestination.Jsii$Proxy that = (EventarcTriggerDestination.Jsii$Proxy) o;

            if (this.cloudRunService != null ? !this.cloudRunService.equals(that.cloudRunService) : that.cloudRunService != null) return false;
            if (this.gke != null ? !this.gke.equals(that.gke) : that.gke != null) return false;
            if (this.httpEndpoint != null ? !this.httpEndpoint.equals(that.httpEndpoint) : that.httpEndpoint != null) return false;
            if (this.networkConfig != null ? !this.networkConfig.equals(that.networkConfig) : that.networkConfig != null) return false;
            return this.workflow != null ? this.workflow.equals(that.workflow) : that.workflow == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudRunService != null ? this.cloudRunService.hashCode() : 0;
            result = 31 * result + (this.gke != null ? this.gke.hashCode() : 0);
            result = 31 * result + (this.httpEndpoint != null ? this.httpEndpoint.hashCode() : 0);
            result = 31 * result + (this.networkConfig != null ? this.networkConfig.hashCode() : 0);
            result = 31 * result + (this.workflow != null ? this.workflow.hashCode() : 0);
            return result;
        }
    }
}
